The application collects genetic data, which relates to the inherited or acquired genetic characteristics of an individual, but the privacy policy does not disclose this. Genetic data is a special category of personal information under regulations like GDPR and is exceptionally sensitive. Failure to inform users about this collection is a very serious issue and likely violates legal requirements for explicit consent and the most stringent data protection measures.